{
  # config,
  pkgs,
  inputs,
  ...
}: {
  imports = [
    ./languages.nix
  ];

  programs.helix = {
    enable = true;

    # add the following packages to helix's path
    package = inputs.helix.packages.${pkgs.system}.default.overrideAttrs (self: {
      makeWrapperArgs = with pkgs;
        self.makeWrapperArgs
        or []
        ++ [
          "--suffix"
          "PATH"
          ":"
          (lib.makeBinPath [
            clang-tools
            marksman
            nil
            nodePackages.bash-language-server
            shellcheck
            java-language-server
            texlab
            tectonic
            zathura
          ])
        ];
    });

    settings = {
      theme = "gruvbox";
      editor = {
        line-number = "relative";
        lsp.display-messages = true;
        scrolloff = 10;
        middle-click-paste = false;
        cursorline = true;
        cursor-shape = {
          insert = "bar";
          normal = "block";
          select = "block";
        };
        auto-format = false;
        idle-timeout = 400;
        color-modes = true;
        soft-wrap.enable = true;
        whitespace = {
          render = {
            space = "none";
            tab = "none";
            newline = "none";
          };
        };
        indent-guides = {
          render = true;
          character = "▏";
          rainbow-option = "dim";
        };
      };
    };
  };
}
